Repository navigation
HERMES_GR_Preproc_edgar
Carles Tena edited this page Jul 15, 2026
·
1 revision
Preprocess the EDGAR inventory.
hermes_gr_preproc EDGAR -i <input_file> \
-o <output_path> \
-y <year> \
[--pollutant_list] \
[--sector_list] \
[--overwrite] \
[--monthly_temporal_profiles] \
[--yearly] \
[--monthly]-
-i,--original_file: Path to the input file. (required) -
-o,--output_path: Output path template for the generated preprocessed files. (required) -
-y,--year: Year to process. (required) -
--monthly_temporal_profiles: Path template to monthly temporal profiles (required if monthly and year != 2010). -
--pollutant_list: Optional list of pollutants to process. -
--sector_list: Optional list of GNFR sectors to process. -
--overwrite: Overwrite existing output files. If not set, existing outputs are skipped. -
--yearly: Process yearly emissions. -
--monthly: Process monthly emissions.
Example for yearly mean output
hermes_gr_preproc EDGAR -i /path/to/yearly/input/file/filename.nc -o /path/to/outputs -y 2010 --yearlyExample for monthly output in 2010
hermes_gr_preproc EDGAR -i /path/to/monthly/input/file/filename.nc -o /path/to/outputs -y 2010 --monthlyExample for monthly output other years
hermes_gr_preproc EDGAR -i /path/to/yearly/input/file/filename.nc -o /path/to/outputs -y 2010 --monthly_temporal_profiles /path/to/profiles --monthly